"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createBranchDiff = createBranchDiff;
exports.requestGit = requestGit;
exports.requestUtils = requestUtils;
var _child_process = require("child_process");
var _fs = require("fs");
var _fileUtils = require("./fileUtils");
var _getSonarProperties = require("../core/sonar-dependencies/getSonarProperties");
var _hash = require("./hash");
async function requestGit(apiDetails, options = {}) {
  const {
    action,
    headers,
    endPoint
  } = apiDetails;
  const body = {
    method: action,
    headers: headers
  };
  return await new Promise(resolve => {
    const request = https.request(endPoint, body, response => {
      var responseChunk = "";
      const fileStream = fs.createWriteStream(getLocalBranchPath());
      response.on("data", data => {
        responseChunk += data;
      });
      response.pipe(fileStream);
      fileStream.on("finish", finish => {
        fileStream.close();
      });
      response.on("error", error => {
        Logger.log(Logger.FAILURE_TYPE, `Error - ${error}`);
      });
      response.on("end", end => {
        // at end
        resolve({});
      });
    });
    request.end();
  });
}

/**
 *@function requestUtils - method execute curl cli request
 * @returns {Promise<Buffer>}
 */

function requestUtils(command) {
  return (0, _child_process.execSync)(command);
}

/**
 * @function createBranchDiff - make giff diff api via curl api
 * @returns {void}
 */

function createBranchDiff() {
  const {
    token,
    gitEndPoint,
    branchDiffPath,
    compareBranch
  } = (0, _fileUtils.getLintConfiguration)();
  const endPoint = `${gitEndPoint}/api/v4/projects/7761/repository/compare?from=${compareBranch}&to=${(0, _getSonarProperties.getBranchName)()}`;
  const command = `curl --header "PRIVATE-TOKEN:${(0, _hash.decrypt)(token, 12)}" "${endPoint}"`;
  (0, _fs.writeFileSync)(branchDiffPath, requestUtils(command));
}